@@ -33,7 +33,7 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 # object fields
 BEGIN { $OID = -1 } # init object field id counter
@@ -311,7 +311,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use Text::Template::Simple::Constants qw( :info DIGEST_MODS );
 use Carp qw( croak );
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 BEGIN {
    if ( IS_WINDOWS ) {
@@ -538,7 +538,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub _compile { shift; return __PACKAGE__->_object->reval(shift) }
 
@@ -571,7 +571,7 @@ use overload q{""} => 'get';
 use Text::Template::Simple::Constants qw( MAX_FL RE_INVALID_CID );
 use Text::Template::Simple::Util      qw( LOG DEBUG DIGEST fatal );
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub new {
    my $class = shift;
@@ -618,7 +618,7 @@ package Text::Template::Simple::Base::Parser;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 use Text::Template::Simple::Util      qw(:all);
 use Text::Template::Simple::Constants qw(:all);
@@ -672,8 +672,7 @@ sub _parse {
    PARSER: foreach my $token ( @{ $toke->tokenize( $raw, $opt->{map_keys} ) } ) {
       my($str, $id, $chomp, undef) = @{ $token };
       LOG( TOKEN => $toke->_visualize_tid($id) . " => $str" ) if DEBUG() > 1;
-      next PARSER if T_DISCARD == $id;
-      next PARSER if T_COMMENT == $id;
+      next PARSER if T_DISCARD == $id || T_COMMENT == $id;
 
       if ( T_DELIMSTART == $id ) { $inside++; next PARSER; }
       if ( T_DELIMEND   == $id ) { $inside--; next PARSER; }
@@ -816,7 +815,7 @@ sub _wrapper {
    ) if DEBUG > 1;
    #LOG( OUTPUT => $wrapper );
    # reset
-   $self->[DEEP_RECURSION] = 0 if $self->[DEEP_RECURSION];
+   $self->[DEEP_RECURSION] = 0; # reset
    return $wrapper;
 }
 
@@ -919,6 +918,7 @@ sub _set_internal_templates {
          }
       )
    ~,
+
    no_monolith => q*
       <%OBJECT%>->compile(
          q~<%FILE%>~,
@@ -945,6 +945,7 @@ sub _set_internal_templates {
    map_keys_init => q(
       <%BUF%> .= <%HASH%>->{"<%KEY%>"} || '';
    ),
+
    map_keys_default => q(
       <%BUF%> .= <%HASH%>->{"<%KEY%>"};
    ),
@@ -955,6 +956,7 @@ sub _set_internal_templates {
          push @{ <%BUF%> }, $_[0];
       };
    ),
+
    dump_sigwarn => q(
       join("\n",
             map {
@@ -1006,7 +1008,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub _include_no_monolith {
    # no monolith eh?
@@ -1156,6 +1158,7 @@ sub _interpolate {
       $inc{SHARE} = join ',', @buf;
    }
 
+   my $share = $inc{SHARE} ? sprintf(qq{'%s', %s}, ($inc{SHARE}) x 2) : 'undef';
    my $rv = $self->_mini_compiler(
                $self->_internal('sub_include') => {
                   OBJECT      => $self->[FAKER_SELF],
@@ -1164,7 +1167,7 @@ sub _interpolate {
                   TYPE        => $type,
                   PARAMS      => $inc{PARAM} ? qq{[$inc{PARAM}]} : 'undef',
                   FILTER      => $filter,
-                  SHARE       => ( $inc{SHARE} ? sprintf(qq{'%s', %s}, ($inc{SHARE}) x 2) : 'undef' ),
+                  SHARE       => $share,
                } => {
                   flatten => 1,
                }
@@ -1190,7 +1193,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub _examine {
    my $self   = shift;
@@ -1257,7 +1260,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub _compiler { shift->[SAFE] ? COMPILER_SAFE : COMPILER }
 
@@ -1306,6 +1309,7 @@ sub _compile {
    my $cache_id = '';
 
    my $as_is = $opt->{_sub_inc} && $opt->{_sub_inc} == T_STATIC;
+
    # first element is the shared names. if it's not defined, then there
    # are no shared variables from top level
    delete $opt->{_share}
@@ -1428,7 +1432,7 @@ package Text::Template::Simple::Tokenizer;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 use constant CMD_CHAR             =>  0;
 use constant CMD_ID               =>  1;
@@ -1768,7 +1772,7 @@ use constant MY_IO_LAYER      => 0;
 use constant MY_INCLUDE_PATHS => 1;
 use constant MY_TAINT_MODE    => 2;
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub new {
    my $class = shift;
@@ -1948,7 +1952,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Caller;
 use Text::Template::Simple::Util qw();
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub stack { # just a wrapper
    my $opt = shift || {};
@@ -1964,7 +1968,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub _compile { shift; return eval shift }
 
@@ -1983,7 +1987,7 @@ use constant HINTS      => 8;
 use constant BITMASK    => 9;
 use Text::Template::Simple::Util qw( ishref fatal );
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 sub stack {
    my $self    = shift;
@@ -2156,7 +2160,7 @@ use Text::Template::Simple::Constants qw(:all);
 use Text::Template::Simple::Util qw( DEBUG LOG ishref fatal );
 use Carp qw( croak );
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 my $CACHE = {}; # in-memory template cache
 
@@ -2570,7 +2574,7 @@ package Text::Template::Simple;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.79_05';
+$VERSION = '0.79_06';
 
 use File::Spec;
 use Text::Template::Simple::Constants qw(:all);
@@ -2832,8 +2836,8 @@ generated with an automatic build tool. If you experience problems
 with this version, please install and use the supported standard
 version. This version is B<NOT SUPPORTED>.
 
-This document describes version C<0.79_05> of C<Text::Template::Simple>
-released on C<2 August 2009>.
+This document describes version C<0.79_06> of C<Text::Template::Simple>
+released on C<5 August 2009>.
 
 B<WARNING>: This version of the module is part of a
 developer (beta) release of the distribution and it is
@@ -3124,17 +3128,6 @@ prefix:
 Just pass the parameters as described above and fetch them via C<@_> inside
 the included file.
 
-=head2 BLOCKS
-
-A block consists of a header part and the content.
-
-   <%| HEADER;
-       BODY
-   %>
-
-C<HEADER> includes the commands and terminated with a semicolon. C<BODY> is the
-actual block content.
-
 =head3 SHARED VARIABLES
 
 C<Text::Template::Simple> compiles every template individually with separate
@@ -3166,6 +3159,17 @@ anything else. If you want to share an array, use an array reference instead:
    %>
    <%* dyna.inc | SHARE: $fooref %>
 
+=head2 BLOCKS
+
+A block consists of a header part and the content.
+
+   <%| HEADER;
+       BODY
+   %>
+
+C<HEADER> includes the commands and terminated with a semicolon. C<BODY> is the
+actual block content.
+
 =head3 BLOCK FILTERS
 
 B<WARNING> Block filters are considered to be experimental. They may be changed
